from django.core.exceptions import ValidationError
from django.core.validators import MaxValueValidator, MinValueValidator
from django.db.models import PositiveIntegerField
from django.utils.html import format_html
from django.utils.translation import gettext_lazy as _


class ProgressBarField(PositiveIntegerField):
    def __init__(self, *args, **kwargs):
        kwargs['validators'] = [MinValueValidator(0), MaxValueValidator(100)]
        super().__init__(*args, **kwargs)

    def clean(self, value, model_instance):
        value = super().clean(value, model_instance)
        if value < 0 or value > 100:
            raise ValidationError(_('Value must be between 0 and 100.'))
        return value

    def get_progress_bar_html(self, value):
        """Generiert den HTML-Code für den Fortschrittsbalken."""
        value = value or 0
        return format_html(
            f'''
            <div class="progress milea-refresh-progress" id="{str(self)}">
                <div class="progress-bar progress-bar-striped progress-bar-animated bg-success" style="width: {value}%" role="progressbar" aria-valuenow="{value}" aria-valuemin="0" aria-valuemax="100" aria-label="{value}% Complete">
                <span class="visually-hidden">{value}% Complete</span>
                </div>
            </div>
            '''
        )




from setuptools import find_packages, setup

setup(
    name='milea-base',
    version='0.5.2',
    packages=find_packages(),
    include_package_data=True,
    install_requires=['django-celery-results>=2.5.1', 'django-celery-beat>=2.5.0', 'django-countries>=7.5.1', 'django-currentuser>=0.7.0', 'django-environ>=0.11.2', 'django-object-actions>=4.2.0', 'django>=5.0.2', 'djangorestframework>=3.14.0', 'pillow>=10.2.0', 'pymysql>=1.1.0', 'requests>=2.31.0', 'milea-users>=0.2', 'milea_notify>=0.2', 'milea_licence>=0.1'],
    author='red-pepper-services',
    author_email='pypi@schiegg.at',
    description='Milea Framework - Milea Base Module',
    license='MIT',
)



from django import template

register = template.Library()

@register.simple_tag
def split_filter_value(value):
    # Teilt den String am letzten Leerzeichen vor der Klammer
    parts = value.rsplit(' ', 1)
    if len(parts) == 2 and parts[1].startswith('(') and parts[1].endswith(')'):
        # Entfernt die Klammern aus dem zweiten Teil
        parts[1] = parts[1][1:-1]
        return parts
    return value, ''
